﻿/// <reference path="../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../rubbish.ts"/>

var NpmPackageSummaryViewModel = (function () {
    function NpmPackageSummaryViewModel(data, feedName) {
        var _this = this;
        this.name = data.name;
        this.description = data.description;
        this.keywords = data.keywords;
        this.latestVersion = data.latestVersion;
        this.publishedDate = data.publishedDate;
        this.isLocal = data.isLocal;
        this.author = data.author;

        this.url = ko.computed(function () {
            return '/npm-feeds/' + encodeURIComponent(feedName) + '/' + encodeURIComponent(_this.name) + '/' + encodeURIComponent(_this.latestVersion);
        });
    }
    return NpmPackageSummaryViewModel;
})();

var BrowseNpmFeedPageViewModel = (function () {
    function BrowseNpmFeedPageViewModel(data) {
        var _this = this;
        this.updateUrl = data.updateUrl;
        this.indexStatusUrl = data.indexStatusUrl;
        this.feedId = data.feedId;
        this.feedName = data.feedName;
        this.indexingConnector = ko.observable(data.indexingConnector);
        this.searchTerm = ko.observable('');
        this.maxResults = ko.observable(20);
        this.packages = ko.observableArray();
        this.isLoading = ko.observable(true);

        this.update();

        this.searchTerm.subscribe(function (v) {
            return _this.update();
        });
        this.maxResults.subscribe(function (v) {
            return _this.update();
        });

        if (data.indexingConnector)
            setTimeout(function () {
                return _this.updateIndexStatus();
            }, 2000);

        $('form').submit(function () {
            _this.searchTerm($('.package-search > input').val());
            return false;
        });
    }
    BrowseNpmFeedPageViewModel.prototype.update = function () {
        var _this = this;
        this.isLoading(true);
        this.packages.removeAll();
        $.ajax({
            url: this.updateUrl,
            data: { feedId: this.feedId, searchTerm: this.searchTerm(), maxResults: this.maxResults() },
            type: 'POST',
            success: function (result) {
                _this.packages.removeAll();
                for (var i = 0; i < result.length; i++) {
                    _this.packages.push(new NpmPackageSummaryViewModel(result[i], _this.feedName));
                }

                _this.isLoading(false);
            }
        });
    };

    BrowseNpmFeedPageViewModel.prototype.updateIndexStatus = function () {
        var _this = this;
        $.ajax({
            url: this.indexStatusUrl,
            data: { feedId: this.feedId },
            type: 'POST',
            success: function (result) {
                _this.indexingConnector(result);
                if (result) {
                    setTimeout(function () {
                        return _this.updateIndexStatus();
                    }, 2000);
                }
            }
        });
    };
    return BrowseNpmFeedPageViewModel;
})();
